<?php

namespace App\Http\Livewire\Dashboard;

use Exception;
use App\Models\User;
use App\Mail\UserInfo;
use Livewire\Component;
use App\Exports\UsersExport;
use App\Mail\UserNotification;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Mail;
use Livewire\WithPagination;
use Maatwebsite\Excel\Facades\Excel;

class ShowTask extends Component
{
    use WithPagination;

    public $task;
    public $search;
    public Collection $users_task_read;
    public Collection $users_task_unread;
    public $selectedUsers = [];
    public $selectAll = false;
    public $selectAllNotRead = false;
    public $selectAllRead = false;

    public $userModal;
    public $isOpen = 0, $readonly;
    public $modalFormVisable = false;

    public $userModel;
    public $emailModel;
    public $descriptionModel;
    public $description;


    public function mount()
    {

//        dd($this->selectedUsers);

        $this->selectedUsers = [];
    }

    public function usersReadAllDocuments()
    {
        return User::with('getUsersAllTaskAndDocuments', 'getUsersAllTasks')
            ->where(function($query) {
                return $query->where('username', 'like', '%' . $this->search . '%')
                    ->orWhere('email', 'like', '%' . $this->search . '%');
            })
            ->whereHas('getUsersAllTasks', function ($query) {
                return $query->where('task_id', $this->task->id)
                    ->where('completed', true);
            })->get();

    }

    public function usersNotReadAllDocuments()
    {
        return User::with('getUsersAllTaskAndDocuments', 'getUsersAllTasks')
            ->where(function($query) {
                return $query->where('username', 'like', '%' . $this->search . '%')
                    ->orWhere('email', 'like', '%' . $this->search . '%');
            })
            ->whereHas('getUsersAllTasks', function ($query) {
                return $query->where('task_id', $this->task->id)
                    ->where('completed', false);
            })->get();

    }

    public function openUsersModal(User $user)
    {
        $this->openModal();
        $this->userModal = $user;
        $this->emailModel = $user->email;
        
    }

    public function openModal()
    {
        $this->isOpen = true;
    }

    public function closeModal()
    {
        $this->isOpen = false;
        $this->resetInputFields();
    }

    private function resetInputFields()
    {
        $this->emailModel = '';
        $this->descriptionModel = '';

        //        $this->readonly = '';
    }

    public function sendNotification()
    {
        // dd($this->description, $this->emailModel, $this->userModal);
        Mail::to($this->emailModel)->queue(new UserNotification($this->userModal, $this->task, $this->description));
        // Mail::to($this->emailModel)->send(new UserInfo($this->userModal, $this->task));
        session()->flash('success', 'Notification is sent to ' . $this->userModal->getCredentials());

        $this->closeModal();
        $this->resetInputFields();
    }

    public function export($ext)
    {
        return Excel::download(new UsersExport($this->selectedUsers), 'users.' . $ext);

    }


    public function render()
    {
//        dd($this->selectedUsers);
        return view('livewire.dashboard.show-task', [
            'dump_users_not_read' => User::with('getUsersAllTaskAndDocuments', 'getUsersAllTasks')
                ->where(function($query) {
                    return $query->where('username', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%');
                })
                ->whereHas('getUsersAllTasks', function ($query) {
                    return $query->where('task_id', $this->task->id)
                        ->where('completed', false);
                })->paginate(15),
            'dump_users_read_all' => User::with('getUsersAllTaskAndDocuments', 'getUsersAllTasks')
                ->where(function($query) {
                    return $query->where('username', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%');
                })
                ->whereHas('getUsersAllTasks', function ($query) {
                    return $query->where('task_id', $this->task->id)
                        ->where('completed', true);
                })->paginate(15),
        ]);
    }

    public function toggleAllCheckboxes(){

        if($this->selectAllNotRead || $this->selectAllRead){
            if($this->selectAllNotRead){
                $array_map_selected_users = array_map('intval', $this->selectedUsers);
                $this->selectedUsers = array_unique(array_merge($array_map_selected_users, $this->usersNotReadAllDocuments()->pluck('id')->toArray()));
                sort($this->selectedUsers);
                $this->selectAllNotRead = true;
            }

            if($this->selectAllRead){
                $array_map_selected_users = array_map('intval', $this->selectedUsers);
                $this->selectedUsers = array_unique(array_merge($array_map_selected_users, $this->usersReadAllDocuments()->pluck('id')->toArray()));
                sort($this->selectedUsers);
                $this->selectAllRead = true;
            }
            if($this->selectAllRead && $this->selectAllNotRead){
                $this->selectedUsers = array_merge($this->usersReadAllDocuments()->pluck('id')->toArray(), $this->usersNotReadAllDocuments()->pluck('id')->toArray());
            }

        }else{
            $this->selectedUsers = [];
            $this->selectAllRead = false;
            $this->selectAllNotRead = false;
        }

    }

    public function clear_all_fields()
    {
        $this->selectedUsers = [];
        $this->selectAllRead = false;
        $this->selectAllNotRead = false;
    }

    public function checkSelectAll($param){
        if($param == 'not_read'){
            $this->selectAllNotRead = false;
        }
        if($param == 'read'){
            $this->selectAllRead = false;
        }
    }

}
