<?php

namespace App\Http\Livewire\Permissions;

use App\Helpers\LogHelper;
use Livewire\Component;
use Spatie\Permission\Models\Permission;

class EditPermission extends Component
{
    protected $listeners = ['showModal'];

    public $permission;
    public $showModal = false;

    public function showModal(Permission $permission)
    {
        $this->permission = $permission;
        $this->showModal = true;
    }

    protected $rules = [
        'permission.name' => 'required|string|min:3',
    ];

    public function render()
    {
        return view('livewire.permissions.edit-permission');
    }

    public function closeModal()
    {
        $this->resetErrorBag();
    }

    public function save()
    {
        try {
            $this->validate();
            $this->permission->save();
            $this->showModal = false;
            $this->emit('refreshComponent');

            $permission_name = $this->permission->name;
            $message = __('messages.Permission') . " $permission_name " . __('messages.is Edited');
            $this->emit('successAlert', $message);
            
            $messageLog = "Дозволата $permission_name е ажурирана";
            $data = ['permission_name' => $permission_name, 'permission' => $this->permission];
            LogHelper::logInfo($messageLog, $data);
        } catch (\Exception $e) {
            $this->addError('error', $e->getMessage());

            $message = $e->getMessage();
            $data = ['permission' => $this->permission, 'error' => $e->getMessage()];
            LogHelper::logMessageError($message, $data);
        }
    }
}
