<?php

namespace App\Http\Livewire\Users;

use App\Models\User;
use Livewire\Component;
use App\Helpers\LogHelper;
use App\Exports\UsersDeleteExport;
use Illuminate\Support\Collection;
use Maatwebsite\Excel\Facades\Excel;

class UserArchiveTable extends Component
{

    public Collection $users;
    public Collection $selectedUsers;
    public $selectAll = false;
    protected $listeners = ['refreshComponent' => '$refresh'];
    protected $delete;
    //    public $selectedUsers = [];

    private function getSelectedUsers()
    {
        return $this->selectedUsers->filter(fn ($u) => $u)->keys();
    }

    public function mount()
    {
        $this->users = User::onlyTrashed()->get();
        $this->selectedUsers = collect();
    }

    public function export($ext)
    {

        if ($this->selectAll) {
            $this->selectAll = false;
            $this->selectedUsers = collect([]);
            return Excel::download(new UsersDeleteExport(User::onlyTrashed()->get()->pluck('id')), 'users_delete_all.' . $ext);
        } else {
            $this->selectAll = false;
            return Excel::download(new UsersDeleteExport($this->getSelectedUsers()), 'users.' . $ext);
        }
    }

    //    public function updatedSelectAll($value){
    //        if($value){
    //            $this->selectedUsers = User::pluck('id');
    //        }else{
    //            $this->selectedUsers = collect([]);
    //        }
    //    }

    public function delete($value)
    {
        $user = User::where('id', $value)->withTrashed()->first();

        if ($user->userData) {
            $user_name = $user->userData->fullName();
        } else {
            $user_name = $user->username;
        }
        $user->forceDelete();
        $this->mount();
        $this->render();

        $message = __('messages.User') . " $user_name " . __('messages.is Permanently Deleted Successfully');
        session()->flash(
            'message',
            $message
        );

        $messageLog = "Корисникоот $user_name e успешно избришан/a засекогаш";
        $data = ['user' => $user];
        LogHelper::logInfo($messageLog, $data);
    }

    public function restore($user_id)
    {
        $user = User::withTrashed()
            ->where('id', $user_id)->first();
        if ($user->userData) {
            $user_name = $user->userData->fullName();
        } else {
            $user_name = $user->username;
        }
        $user->restore();
        $this->mount();
        $this->render();

        $message = __('messages.User') . " $user_name " . __('messages.is Restored Successfully');
        session()->flash(
            'message',
            $message
        );

        $messageLog = "Корисникот $user_name e успешно обновен/а";
        $data = ['user' => $user];
        LogHelper::logInfo($messageLog, $data);
    }

    public function render()
    {
        return view('livewire.users.user-archive-table');
    }
}
