<?php

namespace App\Mail;

use App\Exports\AdminReportExport;
use App\Exports\ReportExport;
use App\Models\Task;
use App\Models\User;
use App\Models\UserTask;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Mail\Mailable;
use Illuminate\Mail\Mailables\Content;
use Illuminate\Mail\Mailables\Envelope;
use Illuminate\Mail\Markdown;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Lang;
use Maatwebsite\Excel\Facades\Excel;

class AdminTaskInfo extends Mailable
{
    use Queueable, SerializesModels;

    /**
     * Create a new message instance.
     *
     * @return void
     */
    public $user;
    public $task;

    public function __construct(User $user, Task $task)
    {
        $this->user = $user;
        $this->task = $task;
    }


    /**
     * Get the message envelope.
     *
     * @return \Illuminate\Mail\Mailables\Envelope
     */
    public function envelope()
    {
        return new Envelope(
            subject: 'Admin Task Info',
        );
    }

    /**
     * Get the message content definition.
     *
     * @return \Illuminate\Mail\Mailables\Content
     */
    public function content()
    {
        return new Content(
            view: 'emails.admin_task_info',
            with: [
                'user' => $this->user,
                'task' => $this->task,
            ],
        );
    }

    /**
     * Get the attachments for the message.
     *
     * @return array
     */
    public function attachments()
    {
        $task_id = $this->task->id;
        $group = UserTask::where('completed', false)
            ->where('task_id', $task_id)
            ->get();


        $path = "reports\\task\\" . $task_id . "\\users_report.xlsx";

        Excel::store(new AdminReportExport($group), $path);
        $location = storage_path('app/'. $path);
        return [
            'nov_rep.xlsx' => $location,
        ];

    }
}
