<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Task extends Model
{
    use HasFactory;
    use SoftDeletes;

    protected $fillable = [
        'title',
        'description',
        'due_date',
        'deleted_by',
        'is_published'
    ];

    public function users()
    {
        return $this->belongsToMany(User::class, 'user_tasks')
            ->withPivot('completed_at')
            ->withPivot('completed')
            ->withTimestamps();
    }

    public function documents()
    {
        return $this->belongsToMany(Document::class, 'document_tasks')->withTimestamps();
    }

    public function reminders()
    {
        return $this->hasMany(ReminderTask::class);
    }

//    stara relacija
//    public function usersTaskDocuments(){
//        return $this->hasMany(UserTaskDocument::class);
//    }

//    nova relacija preku pivot tabela
    public function usersTaskDocuments()
    {
        return $this->belongsToMany(Document::class, 'user_task_documents')
            ->withPivot('user_id', 'document_id', 'is_read', 'opened_at');
    }

    public function usersTask()
    {
        return $this->belongsToMany(User::class, 'user_tasks', 'task_id')->withTimestamps();
    }

    public function reminder_dates()
    {
        return $this->belongsToMany(ReminderDate::class, 'task_reminder_dates', 'task_id', 'reminder_date_id');
    }

}
