<?php

namespace App\Models;

use Laravel\Sanctum\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;
use Illuminate\Notifications\Notifiable;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Notifications\ResetPasswordNotification;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, HasRoles, SoftDeletes, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'username',
        'email',
        'password',
        'default_lang',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    protected $appends = ['first_name', 'last_name'];

    public function sendPasswordResetNotification($token)
    {
        $this->notify(new ResetPasswordNotification($token, $this->default_lang));
    }

    public function getCredentials()
    {
        return ucfirst($this->userData->first_name) . " " . ucfirst($this->userData->last_name);
    }

    public function first_role()
    {
        if ($this->roles && count($this->roles) > 0) {
            return $this->roles()->first()->id;
        }
        return null;
    }

    public function first_role_name()
    {
        if ($this->roles && count($this->roles) > 0) {
            return $this->roles()->first()->name;
        }
        return null;
    }

    public function job_description()
    {
        return $this->hasOneThrough(JobDescription::class, UserData::class, 'user_id', 'id', 'id', 'job_description_id');
    }

    public function licenses()
    {
        return $this->belongsToMany(JobLicense::class, 'user_licenses');
    }

    public function authorizations()
    {
        return $this->belongsToMany(JobAuthorization::class, 'user_authorizations');
    }

    public function userData()
    {
        return $this->hasOne(UserData::class);
    }

    public function getUsersAllTaskAndDocuments()
    {
        return $this->belongsToMany(Task::class, 'user_task_documents')
            ->withPivot('task_id', 'document_id', 'is_read', 'opened_at');
    }

    public function getUsersAllTasks()
    {
        return $this->belongsToMany(Task::class, 'user_tasks')
            ->withPivot('created_at', 'completed');
    }

    protected function getFirstNameAttribute()
    {
        return $this->userData->first_name;
    }

    protected function getLastNameAttribute()
    {
        return $this->userData->last_name;
    }

    public function full_name()
    {
        return $this->first_name . " " . $this->last_name;
    }

    public function getAllLicencesName()
    {

        if (count($this->licenses) > 0) {
            foreach ($this->licenses as $licence) {
                $data[] = $licence->name;
            }
            if (count($data) > 0) {
                return $result = implode(",", $data);
            }
        }
        return "";
    }

    public function getAllAuthorizationsName()
    {

        if (count($this->authorizations) > 0) {
            foreach ($this->authorizations as $authorizations) {
                $data[] = $authorizations->name;
            }
            if (count($data) > 0) {
                return $result = implode(",", $data);
            }
        }
        return "";
    }

    public static function getAllAdminsAndSupervisors()
    {
        return self::whereHas("roles", function ($q) {
            $q->where("name", "admin")->orWhere("name", "supervisor");
        })->get();
    }

    public static function getAllAdminsUsers()
    {
        return self::whereHas("roles", function ($q) {
            $q->where("name", "admin");
        })->get();
    }
}
