<?php

namespace App\Services;

use App\Jobs\TaskReminderAdminJob;
use App\Jobs\TaskReminderJob;
use App\Models\ReminderTask;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Support\Facades\DB;

class TaskReminderService
{
  use DispatchesJobs;

  public function enable_jobs($task)
  {
    $reminders = $task->reminder_dates;

    $job_now = (new TaskReminderJob($task))->delay(Carbon::now()->addSeconds(5));
    $this->dispatch($job_now);

    $task_due_date = $task->due_date;
//    $admin_job_reminder = (new TaskReminderAdminJob($task))->delay(Carbon::now()->addSeconds(5)); # for testing
    $admin_job_reminder = (new TaskReminderAdminJob($task))->delay(Carbon::parse($task_due_date)->subHours(12));
    $admin_job_id = $this->dispatch($admin_job_reminder);

      ReminderTask::create([
          'task_id' => $task->id,
          'job_id' => $admin_job_id,
          'reminded_at' => Carbon::now(),
          'finished' => false
      ]);


       
//      $last_reminder_job = (new TaskReminderJob($task, 'last_reminder'))->delay(Carbon::now()->addSeconds(5));
      $last_reminder_job = (new TaskReminderJob($task, 'last_reminder'))->delay(Carbon::parse($task_due_date));
      $last_reminder_job_id = $this->dispatch($last_reminder_job);

      ReminderTask::create([
          'task_id' => $task->id,
          'job_id' => $last_reminder_job_id,
          'reminded_at' => Carbon::now(),
          'finished' => false
      ]);

    foreach ($reminders as $reminder) {
      $hours = $reminder->hours;
      $hours_delay = $this->set_date($hours, 0, $task);

      $job = (new TaskReminderJob($task, 'reminder'))->delay(Carbon::now()->addHours($hours_delay));
      $job_id = $this->dispatch($job);

      ReminderTask::create([
        'task_id' => $task->id,
        'job_id' => $job_id,
        'reminded_at' => Carbon::now(),
        'finished' => false
      ]);
        }
  }

  public function disable_jobs($task)
  {
    $job_ids = ReminderTask::where('task_id', $task->id)->pluck('job_id');
    DB::table('jobs')->whereIn('id', $job_ids)->delete();
  }

  private function set_date($hours, $date, $task)
  {
    $task_due_date = $task->due_date;
    $difference = Carbon::parse($task_due_date)->subHours($hours);
    $now = Carbon::now();
    return $diff = $difference->diffInHours($now);
  }
}
