<div>
    @can('export users')
        <div class="sm:tw-flex sm:tw-items-center">
            <div class="sm:tw-flex-auto">
                <h1 class="tw-text-xl tw-font-semibold tw-text-gray-900">{{ __('messages.Users Export List') }}</h1>
                <span class="text-sm">* @lang('messages.Please select users to generate your export list')</span>
            </div>
            <div class="tw-mt-4 sm:tw-mt-0 sm:tw-ml-16 sm:tw-flex-none">

                <button wire:click="export('csv')"
                        wire:loading.attr="disabled"
                        type="button"
                        class="text-white bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:ring-blue-300 font-medium rounded-lg text-sm px-5 py-2.5 mr-2 mb-2 dark:bg-blue-600 dark:hover:bg-blue-700 focus:outline-none dark:focus:ring-blue-800">
                    CSV
                </button>

                <button wire:click="export('xlsx')"
                        wire:loading.attr="disabled"
                        type="button"
                        class="focus:outline-none text-white bg-green-700 hover:bg-green-800 focus:ring-4 focus:ring-green-300 font-medium rounded-lg text-sm px-5 py-2.5 mr-2 mb-2 dark:bg-green-600 dark:hover:bg-green-700 dark:focus:ring-green-800">
                    XLS
                </button>
                <button wire:click="export('pdf')"
                        wire:loading.attr="disabled"
                        type="button"
                        class="text-white bg-gray-800 hover:bg-gray-900 focus:outline-none focus:ring-4 focus:ring-gray-300 font-medium rounded-lg text-sm px-5 py-2.5 mr-2 mb-2 dark:bg-gray-500 dark:hover:bg-gray-600 dark:focus:ring-gray-400 dark:border-gray-700">
                    PDF
                </button>
            </div>
        </div>
    @endcan

    <div class="flex flex-col " x-data="AlpineSelect()">
        @if (session()->has('message'))
            <div x-data="{ show: true }" x-show="show" x-init="setTimeout(() => show = false, 3000)" class="bg-teal-100 border-t-4 border-teal-500 rounded-b text-teal-900 px-4 py-3 shadow-md my-3" role="alert">
                <div class="flex">
                    <div>
                        <p class="text-sm">{{ session('message') }}</p>
                    </div>
                </div>
            </div>
        @endif
        <div class="overflow-x-auto relative shadow-md sm:rounded-lg">
            @if(count($this->selectedUsers)>0)
                <div class="flex w-full group px-4 sm:p-6">
                    <h3 class="font-semibold text-gray-900 dark:text-white">{{ __('messages.Selected Users') }} : {{ count($this->selectedUsers)>0 ? count($this->selectedUsers) : "0"  }}</h3>
                    <button x-on:click="$wire.clear_all_fields()"
                            class="ml-5 px-2 py-1 font-semibold text-sm bg-gray-500 text-white rounded-full shadow-sm">@lang('messages.Clear Selected Users')
                    </button>
                </div>
            @endif
            <div class="flex items-center pb-4">
                <label for="table-search" class="sr-only">Search</label>
                <div class="relative">
                    <div class="flex absolute inset-y-0 left-0 items-center pl-3 pointer-events-none">
                        <svg class="w-5 h-5 text-gray-500 dark:text-gray-400" aria-hidden="true" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" d="M8 4a4 4 0 100 8 4 4 0 000-8zM2 8a6 6 0 1110.89 3.476l4.817 4.817a1 1 0 01-1.414 1.414l-4.816-4.816A6 6 0 012 8z" clip-rule="evenodd"></path></svg>
                    </div>
                    <input
                        wire:model="search"
                        type="search" placeholder="{{ __('messages.Search users') }}"
                        type="text"
                        id="table-search"
                        class="block p-2 pl-10 w-80 text-sm text-gray-900 bg-gray-50 rounded-lg border border-gray-300 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500"
                        placeholder="Search for user"
                        >

                </div>
                <div class="ml-12 w-48">
                    <select
                        wire:model="role"
                        x-on:change="$wire.changeRole()"
                        placeholder="{{ __('messages.Select Role') }}..."
                        autocomplete="off"
                        {{-- class="block w-full rounded-sm cursor-pointer focus:outline-none" --}}
                        class="inline-flex items-center w-full text-gray-500 bg-white border border-gray-300 focus:outline-none hover:bg-gray-100 focus:ring-4 focus:ring-gray-200 font-medium rounded-lg text-sm px-3 py-1.5 dark:bg-gray-700 dark:text-white dark:border-gray-600 dark:hover:bg-gray-600 dark:hover:border-gray-600 dark:focus:ring-gray-700"
                        >
                        <option value="">{{ __('messages.Select Role') }}</option>
                        @foreach ($roles as $role)
                            <option value="{{$role->name}}">{{$role->name}}</option>
                        @endforeach
                    </select>
                </div>
            </div>
            <table class="w-full text-sm text-left text-gray-500 dark:text-gray-400">
                <thead class="text-xs text-gray-700 uppercase bg-gray-50 dark:bg-gray-700 dark:text-gray-400">
                    <tr>
                        <th scope="col" class="p-4">
                            @can('export users')
                            <div
                                class="flex items-center"
                                x-data="{
                                    selectAll : false,
                                    selectedUser_id: [],
                                    toggleAllCheckboxes() {
                                        this.selectAll = !this.selectAll
                                        this.selectedUser_id = [];

                                        checkboxes = document.querySelectorAll('input[name=user_id]');
                                        [...checkboxes].map((el) => {
                                            el.checked = this.selectAll;
                                            (this.selectAll) ? this.selectedUser_id.push(el.value) : this.selectedUser_id = [];
                                        })
                                    },
                                        get showselectedUser_id(){
                                            return (this.selectedUser_id.length > 0);
                                        }
                                    }">
                                <input
                                    wire:model="selectAll"
                                    name="selectAll"
                                    x-on:click="$wire.toggleAllCheckboxes()"
                                    type="checkbox"
                                    class="w-4 h-4 text-blue-600 bg-gray-100 rounded border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                                    >
                                <label for="checkbox-select_all" class="sr-only">
                                    {{ __('messages.Select All') }}
                                </label>
                            </div>
                            @endcan
                        </th>
                        <th scope="col" class="py-3 px-6">
                            {{ __('messages.Username') }}
                        </th>
                        <th scope="col" class="py-3 px-6">
                            {{ __('messages.Email') }}
                        </th>
                        <th scope="col" class="py-3 px-6">
                            {{ __('messages.Roles') }}
                        </th>
                        <th scope="col" class="py-3 px-6 text-center">
                            {{ __('messages.Actions') }}
                        </th>
                    </tr>
                </thead>
                <tbody>
                @foreach ($users as $user)
                    <tr class="bg-white border-b dark:bg-gray-800 dark:border-gray-700 hover:bg-gray-50 dark:hover:bg-gray-600">
                        <td class="p-4 w-4">
                            <div class="flex items-center">
                                <input
                                    wire:model="selectedUsers"
                                    wire:key="{{ $user->id }}"
                                    name="user_id"
                                    value="{{ $user->id }}"
                                    type="checkbox"
                                    class="w-4 h-4 text-blue-600 bg-gray-100 rounded border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                                    >
                                <label for="checkbox-user_id" class="sr-only">user_id</label>
                            </div>
                        </td>
                        <th scope="row" class="py-2 px-6 font-medium text-gray-900 whitespace-nowrap dark:text-white">
                            {{ $user->username }}
                        </th>
                        <td class="py-2 px-6">
                            {{ $user->email }}
                        </td>
                        <td class="py-2 px-6">
                            @foreach ($user->roles as $roles)
                                <span
                                    class="inline-flex px-2 text-sm font-semibold leading-5 text-green-800 bg-green-100 rounded-full">
                                    {{ $roles->name }}
                                </span>
                            @endforeach
                        </td>
                        @can('manage users')
                        <td class="text-center py-2 px-6">
                            <button
                                x-data="{}"
                                x-on:click="window.livewire.emitTo('users.edit-user','showModal', {{ $user }})"
                                class="inline-flex items-center text-white bg-green-700 hover:bg-green-800 focus:outline-none focus:ring-4 focus:ring-green-300 font-medium rounded-full text-sm h-10 px-5 m-2 text-center dark:bg-green-600 dark:hover:bg-green-700 dark:focus:ring-green-800"
                                type="button"
                                >
                                <svg fill="#ffffff" xmlns="http://www.w3.org/2000/svg"  viewBox="0 0 32 32" width="20px" height="20px">
                                    <path d="M 23.90625 3.96875 C 22.859375 3.96875 21.8125 4.375 21 5.1875 L 5.1875 21 L 5.125 21.3125 L 4.03125 26.8125 L 3.71875 28.28125 L 5.1875 27.96875 L 10.6875 26.875 L 11 26.8125 L 26.8125 11 C 28.4375 9.375 28.4375 6.8125 26.8125 5.1875 C 26 4.375 24.953125 3.96875 23.90625 3.96875 Z M 23.90625 5.875 C 24.410156 5.875 24.917969 6.105469 25.40625 6.59375 C 26.378906 7.566406 26.378906 8.621094 25.40625 9.59375 L 24.6875 10.28125 L 21.71875 7.3125 L 22.40625 6.59375 C 22.894531 6.105469 23.402344 5.875 23.90625 5.875 Z M 20.3125 8.71875 L 23.28125 11.6875 L 11.1875 23.78125 C 10.53125 22.5 9.5 21.46875 8.21875 20.8125 Z M 6.9375 22.4375 C 8.136719 22.921875 9.078125 23.863281 9.5625 25.0625 L 6.28125 25.71875 Z"/>
                                </svg>
                                {{ __('messages.Edit') }}
                            </button>
                            <div class="inline-flex">
                                @include('components.modals.archive-modal', ['value' => $user->id, 'name' => $user->username])
                            </div>
                        </td>
                        @endcan
                    </tr>
                @endforeach
                </tbody>
            </table>
        </div>
        <div class="w-full items-center bg-center text-center">
            {{ $users->links() }}
        </div>
    </div>
    <div wire:key="users.edit-user">
        <livewire:users.edit-user>
    </div>
</div>

@push('scripts')
<script>
    function AlpineSelect(){
        return {
            selectAll: false,
        };
    }
</script>
@endpush
